pub struct ChainMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on chain resources.
It is not used directly, but through the MyBusiness hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_mybusiness4 as mybusiness4;
use mybusiness4::{MyBusiness, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = MyBusiness::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)` and `search(...)`
// to build up your call.
let rb = hub.chains();Implementations
Sourceimpl<'a, C> ChainMethods<'a, C>
impl<'a, C> ChainMethods<'a, C>
Sourcepub fn get(&self, name: &str) -> ChainGetCall<'a, C>
pub fn get(&self, name: &str) -> ChainGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the specified chain. Returns NOT_FOUND if the
chain does not exist.
Arguments
name- The chain’s resource name, in the formatchains/{chain_place_id}.
Sourcepub fn search(&self) -> ChainSearchCall<'a, C>
pub fn search(&self) -> ChainSearchCall<'a, C>
Create a builder to help you perform the following task:
Searches the chain based on chain name.