pub struct ListLocalPostsResponse {
pub local_posts: Option<Vec<LocalPost>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListLocalPosts
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations local posts list accounts (response)
Fields
local_posts: Option<Vec<LocalPost>>The returned list of local posts.
next_page_token: Option<String>If there are more local posts than the requested page size, then this field
is populated with a token to fetch the next page of local posts on a
subsequent call to ListLocalPosts.